/*
** $Id: parse.h,v 1.2 2001/04/25 17:17:04 mhucka Exp $
** $Log: parse.h,v $
** Revision 1.2  2001/04/25 17:17:04  mhucka
** Misc. small changes to improve portability and address compiler warnings.
**
** Revision 1.1  1992/12/11 19:05:08  dhb
** Initial revision
**
*/

#ifndef PARSE_H
#define PARSE_H

/*
** Parsing related type and constant definitions
*/

#include "result.h"

typedef struct _pn
  {
    Result	pn_val;
    struct _pn	*pn_left;
    struct _pn	*pn_right;
  } ParseNode;

typedef union _yyvals
  {
    int		iconst;
    double	fconst;
    char	*str;
    ParseNode	*pn;
  } YYSTYPE;


extern ParseNode *PTNew();
extern Result PTEval();


#endif
